@@ -5,7 +5,7 @@ import asyncio
 import datetime
 import json
 import logging
-from typing import Any, Callable, Optional
+from typing import Any, Callable
 
 import aiohttp  # type: ignore
 from aiohttp.client_exceptions import ContentTypeError, ServerTimeoutError
@@ -16,6 +16,7 @@ from .exceptions import (
     AlreadyListening,
     AuthenticationError,
     MissingMethod,
+    MissingSerial,
     ParseJSONError,
     UnknownError,
 )
@@ -181,8 +182,8 @@ class OpenEVSE:
         self._config: dict = {}
         self._override = None
         self._ws_listening = False
-        self.websocket: Optional[OpenEVSEWebsocket] = None
-        self.callback: Optional[Callable] = None
+        self.websocket: OpenEVSEWebsocket | None = None
+        self.callback: Callable | None = None
         self._loop = None
 
     async def process_request(
@@ -287,6 +288,28 @@ class OpenEVSE:
                 self.url, self._update_status, self._user, self._pwd
             )
 
+    async def test_and_get(self) -> dict:
+        """Test connection.
+
+        Return model serial number as dict
+        """
+        url = f"{self.url}config"
+        data = {}
+
+        response = await self.process_request(url, method="get")
+        if "wifi_serial" in response:
+            serial = response["wifi_serial"]
+        else:
+            _LOGGER.debug("Older firmware detected, missing serial.")
+            raise MissingSerial
+        if "buildenv" in response:
+            model = response["buildenv"]
+        else:
+            model = "unknown"
+
+        data = {"serial": serial, "model": model}
+        return data
+
     def ws_start(self):
         """Start the websocket listener."""
         if self._ws_listening:
@@ -406,7 +429,7 @@ class OpenEVSE:
         """Get the manual override status."""
         url = f"{self.url}override"
 
-        _LOGGER.debug("Geting data from %s", url)
+        _LOGGER.debug("Getting data from %s", url)
         response = await self.process_request(url=url, method="get")
         return response
 
@@ -465,9 +488,9 @@ class OpenEVSE:
 
     async def clear_override(self) -> None:
         """Clear the manual override status."""
-        url = f"{self.url}overrride"
+        url = f"{self.url}override"
 
-        _LOGGER.debug("Clearing manual overrride %s", url)
+        _LOGGER.debug("Clearing manual override %s", url)
         response = await self.process_request(url=url, method="delete")
         _LOGGER.debug("Toggle response: %s", response["msg"])
 
@@ -668,7 +691,7 @@ class OpenEVSE:
 
     @property
     def ambient_temperature(self) -> float | None:
-        """Return the temperature of the ambient sensor, in degrees Celcius."""
+        """Return the temperature of the ambient sensor, in degrees Celsius."""
         assert self._status is not None
         temp = None
         if "temp" in self._status and self._status["temp"]:
@@ -681,7 +704,7 @@ class OpenEVSE:
     def rtc_temperature(self) -> float | None:
         """Return the temperature of the real time clock sensor.
 
-        In degrees Celcius.
+        In degrees Celsius.
         """
         assert self._status is not None
         temp = self._status["temp2"] if self._status["temp2"] else None
@@ -693,7 +716,7 @@ class OpenEVSE:
     def ir_temperature(self) -> float | None:
         """Return the temperature of the IR remote sensor.
 
-        In degrees Celcius.
+        In degrees Celsius.
         """
         assert self._status is not None
         temp = self._status["temp3"] if self._status["temp3"] else None
@@ -703,7 +726,7 @@ class OpenEVSE:
 
     @property
     def esp_temperature(self) -> float | None:
-        """Return the temperature of the ESP sensor, in degrees Celcius."""
+        """Return the temperature of the ESP sensor, in degrees Celsius."""
         assert self._status is not None
         if "temp4" in self._status:
             temp = self._status["temp4"] if self._status["temp4"] else None
@@ -712,7 +735,7 @@ class OpenEVSE:
         return None
 
     @property
-    def time(self) -> Optional[datetime.datetime]:
+    def time(self) -> datetime.datetime | None:
         """Get the RTC time."""
         assert self._status is not None
         if "time" in self._status:
@@ -793,14 +816,16 @@ class OpenEVSE:
         return None
 
     @property
-    def charging_power(self) -> float:
+    def charging_power(self) -> float | None:
         """Return the charge power.
 
         Calculate Watts base on V*I
         """
-        assert self._status is not None
-        value = round(self._status["voltage"] * self._status["amp"], 2)
-        return value
+        if self._status is not None and any(
+            key in self._status for key in ["voltage", "amp"]
+        ):
+            return round(self._status["voltage"] * self._status["amp"], 2)
+        return None
 
     # There is currently no min/max amps JSON data
     # available via HTTP API methods
